# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.controllers.exchange_rates_controller import ExchangeRatesController


class ExchangeRatesControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(ExchangeRatesControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = ExchangeRatesController(cls.config, cls.response_catcher)

    # Get BTC-to-Currency exchange rates
    #
    def test_get_btc_to_currencyexchangerates(self):

        # Perform the API call through the SDK function
        self.controller.get_btc_to_currencyexchangerates()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

